# dr.botzo - a pluggable IRC bot written in Python
# Copyright (C) 2010  Brian S. Stephan
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from ConfigParser import ConfigParser, NoSectionError, NoOptionError
import os
import re
import sys
import inspect

from irclib import irclib
from modules import *

modlist = []
moduleList = [ "Countdown", "Dice", "IrcAdmin", "GoogleTranslate", "Seen", "FactFile" ]
modObjs = []

# DrBotServerConnection subclasses irclib's ServerConnection, in order to expand
# privmsg.

class DrBotServerConnection(irclib.ServerConnection):

    def privmsg(self, target, text):
        # Send a PRIVMSG command.
        # TODO: length limiting or splitting
        self.send_raw("PRIVMSG %s :%s" % (target, text))

# DrBotIRC subclasses irclib's IRC, in order to create a DrBotServerConnection.

class DrBotIRC(irclib.IRC):

    def server(self):
         c = DrBotServerConnection(self)
         self.connections.append(c)
         return c

# read config file

config = ConfigParser({'debug': 'false'})
config.read([os.path.expanduser('~/.dr.botzo.cfg'), 'dr.botzo.cfg'])

# load necessary options
try:
    # load connection info
    botserver   = config.get('IRC', 'server')
    botport     = config.getint('IRC', 'port')
    botnick     = config.get('IRC', 'nick')
    botircname  = config.get('IRC', 'name')
except NoSectionError as e:
    sys.exit("Aborted due to error with necessary configuration: " + str(e))
except NoOptionError as e:
    sys.exit("Aborted due to error with necessary configuration: " + str(e))

# load additional options
irclib.DEBUG = config.getboolean('IRC', 'debug')

# start up the IRC bot

# create IRC and server objects and connect
irc = DrBotIRC()
server = irc.server().connect(botserver, botport, botnick, botircname)

# load features
try:
    cfgmodlist = config.get('modules', 'modlist')

    mods = cfgmodlist.split(',')
    for mod in mods:
        # try to load each module
        eval(mod + '.' + mod + '(config, server, modlist)')
except NoSectionError as e:
    print("You seem to be missing a modules config section, which you probably wanted.")
except NoOptionError as e:
    print("You seem to be missing a modlist config option, which you probably wanted.")

# loop forever
irc.process_forever()

# vi:tabstop=4:expandtab:autoindent
# kate: indent-mode python;indent-width 4;replace-tabs on;
